@@ -1,9 +1,8 @@
 use rand::Rng;
 use rust_hdl::core::prelude::*;
 use rust_hdl::hls::prelude::*;
-use rust_hdl::widgets::prelude::*;
 
-#[derive(LogicBlock, Default)]
+#[derive(LogicBlock)]
 struct ControllerTest {
     to_cpu: FIFOReadController<Bits<16>>,
     from_cpu: FIFOWriteController<Bits<16>>,
@@ -16,6 +15,22 @@ struct ControllerTest {
     clock: Signal<In, Clock>,
 }
 
+impl Default for ControllerTest {
+    fn default() -> Self {
+        Self {
+            to_cpu: Default::default(),
+            from_cpu: Default::default(),
+            to_cpu_fifo: Default::default(),
+            from_cpu_fifo: Default::default(),
+            controller: Default::default(),
+            bridge: Bridge::new(["port", "iport"]),
+            port: Default::default(),
+            iport: Default::default(),
+            clock: Default::default(),
+        }
+    }
+}
+
 impl Logic for ControllerTest {
     #[hdl_gen]
     fn update(&mut self) {
@@ -23,10 +38,19 @@ impl Logic for ControllerTest {
         self.to_cpu_fifo.clock.next = self.clock.val();
         self.from_cpu_fifo.clock.next = self.clock.val();
         // Connect the test interfaces
-        FIFOWriteController::<Bits<16>>::join(&mut self.from_cpu, &mut self.from_cpu_fifo.bus_write);
-        FIFOReadResponder::<Bits<16>>::join(&mut self.from_cpu_fifo.bus_read, &mut self.controller.from_cpu);
+        FIFOWriteController::<Bits<16>>::join(
+            &mut self.from_cpu,
+            &mut self.from_cpu_fifo.bus_write,
+        );
+        FIFOReadResponder::<Bits<16>>::join(
+            &mut self.from_cpu_fifo.bus_read,
+            &mut self.controller.from_cpu,
+        );
         FIFOReadController::<Bits<16>>::join(&mut self.to_cpu, &mut self.to_cpu_fifo.bus_read);
-        FIFOWriteResponder::<Bits<16>>::join(&mut self.to_cpu_fifo.bus_write, &mut self.controller.to_cpu);
+        FIFOWriteResponder::<Bits<16>>::join(
+            &mut self.to_cpu_fifo.bus_write,
+            &mut self.controller.to_cpu,
+        );
         self.controller.clock.next = self.clock.val();
         // Connect the controller to the bridge
         SoCBusController::<16, 2>::join(&mut self.controller.bus, &mut self.bridge.upstream);
